@@ -1,44 +1,37 @@
 ## ----setup, include=FALSE-----------------------------------------------------
 knitr::opts_chunk$set(echo = TRUE, error = FALSE, fig.retina = 1, dpi = 80)
-knitr::opts_knit$set(root.dir = system.file('extdata', 
-                                            package='voluModel'))
 
 ## ----generating data for plotting---------------------------------------------
 library(voluModel) # Because of course
 library(ggplot2) # For fancy plotting
-library(rgdal, 
-        options("rgdal_show_exportToProj4_warnings"="none")) # For vector stuff. Will eventually be replaced with sf.
-library(raster) # For raster stuff. Will eventually be replaced with terra.
 library(viridisLite) # For high-contrast plotting palettes
 library(dplyr) # To filter data
 library(terra) # Now being transitioned in
 library(sf) # Now being transitioned in
 
 # Load data
-load(system.file("extdata/oxygenSmooth.RData", 
-                 package='voluModel'))
-
-td <- tempdir()
-unzip(system.file("extdata/woa18_decav_t00mn01_cropped.zip", 
-                  package = "voluModel"),
-      exdir = paste0(td, "/temperature"), junkpaths = T)
-temperature <- readOGR(dsn = paste0(td, "/temperature"), 
-                       layer ="woa18_decav_t00mn01_cropped")
-unlink(paste0(td, "/temperature"), recursive = T)
-
-temperature@data[temperature@data == -999.999] <- NA
+oxygenSmooth <- rast(system.file("extdata/oxygenSmooth.tif", 
+                                 package='voluModel'))
 
 occs <- read.csv(system.file("extdata/Steindachneria_argentea.csv", 
                              package='voluModel'))
 
-# Creating a RasterBrick
-temperature <- rasterFromXYZ(cbind(temperature@coords,
-                                   temperature@data))
+# Temperature
+td <- tempdir()
+unzip(system.file("extdata/woa18_decav_t00mn01_cropped.zip", 
+                  package = "voluModel"),
+      exdir = paste0(td, "/temperature"), junkpaths = T)
+temperature <- vect(paste0(td, "/temperature/woa18_decav_t00mn01_cropped.shp"))
+
+# Creating a SpatRaster vector
+template <- centerPointRasterTemplate(temperature)
+tempTerVal <- rasterize(x = temperature, y = template, field = names(temperature))
 
 # Get names of depths
 envtNames <- gsub("[d,M]", "", names(temperature))
 envtNames[[1]] <- "0"
-names(temperature) <- envtNames
+names(tempTerVal) <- envtNames
+temperature <- tempTerVal
 
 # Oxygen processing
 names(oxygenSmooth) <- names(temperature)
@@ -48,7 +41,7 @@ occurrences <- occs %>% dplyr::select(decimalLongitude, decimalLatitude, depth)
   distinct() %>% filter(dplyr::between(depth, 1, 2000))
 
 # Gets the layer index for each occurrence by matching to depth
-layerNames <- as.numeric(gsub("[X]", "", names(temperature)))
+layerNames <- as.numeric(names(temperature))
 occurrences$index <- unlist(lapply(occurrences$depth, 
                                    FUN = function(x) which.min(abs(layerNames - x))))
 indices <- unique(occurrences$index)
@@ -71,22 +64,22 @@ land <- rnaturalearth::ne_countries(scale = "small", returnclass = "sf")[1]
 
 # Study region
 studyRegion <- marineBackground(occsWdata, buff = 1000000)
-studyRegion <- sf::st_as_sf(studyRegion)
-studyRegion <- sf::st_transform(studyRegion, crs(land))
 
 # Get limits
 tempLims <- quantile(occsWdata$temperature,c(0, 1))
 aouLims <- quantile(occsWdata$AOU,c(0, 1))
 
 # Reclassify environmental bricks to presence/absence
-temperaturePresence <- reclassify(temperature, 
-                                  rcl = c(-Inf,tempLims[[1]],0,
-                                          tempLims[[1]], tempLims[[2]], 1,
-                                          tempLims[[2]], Inf, 0))
-AOUpresence <- reclassify(oxygenSmooth, 
-                          rcl = c(-Inf, aouLims[[1]],0,
-                                  aouLims[[1]], aouLims[[2]], 1,
-                                  aouLims[[2]], Inf, 0))
+temperaturePresence <- classify(temperature, 
+                                rcl = matrix(c(-Inf,tempLims[[1]],0,
+                                               tempLims[[1]], tempLims[[2]], 1,
+                                               tempLims[[2]], Inf, 0),
+                                             ncol = 3, byrow = TRUE))
+AOUpresence <- classify(oxygenSmooth, 
+                        rcl = matrix(c(-Inf, aouLims[[1]],0,
+                                       aouLims[[1]], aouLims[[2]], 1,
+                                       aouLims[[2]], Inf, 0), 
+                                     ncol = 3, byrow = TRUE))
 
 # Put it all together
 envelopeModel3D <- temperaturePresence * AOUpresence
@@ -94,14 +87,11 @@ envelopeModel3D <- mask(crop(envelopeModel3D, studyRegion),
                         mask = studyRegion)
 names(envelopeModel3D) <- names(temperature)
 rm(AOUpresence, downsampledOccs, occurrences, temperaturePresence, 
-   tempPoints, aouLims, envtNames, i, indices, layerNames, td, tempLims)
+   tempPoints, aouLims, envtNames, i, indices, layerNames, tempLims)
 
-## ----pointMap, warning=FALSE, message=FALSE, eval=FALSE-----------------------
-#  pointMap(occs = occs, land = land, landCol = "black", spName = "Steindachneria argentea",
-#           ptSize = 2, ptCol = "orange")
-
-## ----pointMap plot, echo=FALSE, out.width = '100%', out.height= '100%'--------
-knitr::include_graphics("pointMap.png")
+## ----pointMap, warning=FALSE, message=FALSE, eval=TRUE------------------------
+pointMap(occs = occs, land = land, landCol = "black", spName = "Steindachneria argentea", 
+         ptSize = 2, ptCol = "orange")
 
 ## ----pointCompMap, warning=FALSE, message=FALSE-------------------------------
 pointCompMap(occs1 = occs, occs1Col = "red", occs1Name = "Raw", 
@@ -112,7 +102,8 @@ pointCompMap(occs1 = occs, occs1Col = "red", occs1Name = "Raw",
 ## ----oneRasterPlot------------------------------------------------------------
 oneRasterPlot(rast = temperature[[1]],
               land = land, title = "Sea Surface Temperature, WOA 2018",
-              landCol = "black", n = 11, option = "mako")
+              landCol = "black", n = 11, option = "mako",
+              varName = "Temperature")
 
 ## ----rasterComp---------------------------------------------------------------
 rasterComp(rast1 = envelopeModel3D[[1]], rast1Name = "Surface",
@@ -121,11 +112,14 @@ rasterComp(rast1 = envelopeModel3D[[1]], rast1Name = "Surface",
            title = "Suitability of Habitat for Luminous Hake\nAt Two Different Depths")
 
 ## ----plotLayers---------------------------------------------------------------
-layerNames <- as.numeric(gsub("[X]", "", names(envelopeModel3D)))
+layerNames <- as.numeric(names(envelopeModel3D))
 occsWdata$index <- unlist(lapply(occsWdata$depth, FUN = function(x) which.min(abs(layerNames - x))))
 indices <- unique(occsWdata$index)
 
-plotLayers(envelopeModel3D[[min(indices):max(indices)]], 
-           title = "Envelope Model of Luminous Hake,\n 20 to 700m",
-           land = land, landCol = "black")
+layerPlot <- plotLayers(envelopeModel3D[[min(indices):max(indices)]], 
+                        title = "Envelope Model of Luminous Hake,\n 20 to 700m",
+                        land = land, landCol = "black")
+
+## ----cleanup temporary directory----------------------------------------------
+unlink(td, recursive = T)
 
